<?php
namespace AkTest\View\Renderer;

use Ak\Test\AbstractTestCase;
use Ak\View\HelperPluginManager;
use AkTest\View\TestConfigProvider;
use Laminas\View\Renderer\PhpRenderer;
use Laminas\View\Renderer\RendererInterface;

/**
 * Class PhpRendererTest
 *
 * @package AkTest\View\Renderer
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/view
 */
class PhpRendererTest extends AbstractTestCase
{
    public $providers = [
        TestConfigProvider::class,
    ];

    public function testIsRegistered()
    {
        $container = $this->getContainer();

        $this->assertTrue($container->has(PhpRenderer::class));
        $this->assertInstanceOf(PhpRenderer::class, $container->get(RendererInterface::class));
    }

    public function testHelperManagerIsInjected()
    {
        $container = $this->getContainer();

        $manager = $container->get(HelperPluginManager::class);
        /** @var PhpRenderer $renderer */
        $renderer = $container->get(RendererInterface::class);

        $this->assertSame($manager, $renderer->getHelperPluginManager());
    }

    public function testCanRenderViewScripts()
    {
        $container = $this->getContainer();
        /** @var RendererInterface $renderer */
        $renderer = $container->get(RendererInterface::class);

        $rendered = $renderer->render('template');
        $this->assertEquals('<h1>Template</h1>', $rendered);
    }
}
